!$Id: uves_common.prg,v 1.24 2010/02/01 17:12:56 amodigli Exp $
!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
!COPYRIGHT (c) 8004 European Southern Observatory
!LICENSE
!
!PROJECT:   VLT Data Flow System
!AUTHOR:    A.Modigliani - ESO/DMD/DPG
!SUBSYSTEM: UVES Instrument Pipeline
!PURPOSE:   MIDAS interface procedure for UVES pipeline recipe.
!
!$Name: uves-4_9_1 $
!$Revision: 1.24 $
!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
!define/parameter p1 ? c "Enter result data"
!define/parameter p2 ? c "Enter input frames"
!define/parameter p3 ? c "Enter calib data"
!define/parameter p4 ? c "Enter recipe name"
!define/parameter p5 ? c "Enter recipe options"

define/local resultFrames/c/1/150 "{P1}"
define/local inputFrames/c/1/150 "{P2}"
define/local calibData/c/1/150 "{P3}"
define/local recipeName/c/1/80 "{P4}"
define/local recipeSpecs/c/1/400 " {recipeName} {p5} {p6} {p7} {p8} {recipeName}.sof"
w/o "recipespecs={recipeSpecs}"

define/local didPath/c/1/200 " -I"
define/local didList/c/1/200 " -D"
define/local pafList/c/1/200 " -p *.paf"

define/local outDirOption/c/1/20 " --output-dir="
define/local proPrefixOption/c/1/20 " --output-prefix="
define/local recInstOption/c/1/20 " --recipe-dir="
define/local logFileOption/c/1/20  " --log-file="

define/local proDir/c/1/60 ""
define/local proPrefix/c/1/60 ""
define/local logFile/c/1/60 ""
define/local recipeInst/c/1/60 "$PIPE_HOME/uves"

define/local esorex_opt/c/1/250 ""
define/local recipe_opt/c/1/100 ""
define/local esorex_bin/c/1/10 "esorex "

define/local cmdLine/c/1/400 " " all
define/local line/c/1/400 " " all

define/local pos/i/1/1 0

define/local fid/i/1/2 0 all
define/local sid/i/1/2 0 all


log/rec {recipeName} IN

pos = m$indexb(resultFrames, "/") - 1

proDir = resultFrames(1:{pos})
pos = pos + 2
proPrefix = resultFrames({pos}:)
logFile = proPrefix // ".log"

!with options..
$echo {esorex_bin}                 "\\\\" > esorex_cmd_file
$echo {recInstOption}{recipeInst}  "\\\\" >> esorex_cmd_file
$echo {outDirOption}{proDir}       "\\\\" >> esorex_cmd_file
$echo {proPrefixOption}{proPrefix} "\\\\" >> esorex_cmd_file
$echo {logFileOption}{logFile}     "\\\\" >> esorex_cmd_file
$echo {recipeSpecs}                      >> esorex_cmd_file
$chmod +x esorex_cmd_file

!Old way
!esorex_opt = recInstOption // recipeInst -
!             // outDirOption // proDir -
!             // proPrefixOption // proPrefix  -
!          // logFileOption // logFile // recipeSpecs
!-------------------------------------------------------
! The following piece of code is a TEMPORARY PATCH
! to get the RAW and CALIB tags into the set of frames
! file. It has to stay there until the RBS has been
! patched and will be removed afterwards
!-------------------------------------------------------
open/file {recipeName}.sof write sid
if sid(1) .lt. 0 then
    return 1
endif

open/file {inputFrames} read fid
if fid(1) .lt. 0 then
    return 1
endif

raw_loop:
    read/file {fid(1)} line
    if fid(2) .gt. 0 then
        fid(2) = fid(2) + 1
        line({fid(2)}:) = " RAW"
        write/file {sid(1)},key line
        goto raw_loop
    endif
close/file {fid(1)}

if calibData .ne. "?" then
    open/file {calibData} read fid
    if fid(1) .lt. 0 then
        return 1
    endif

cal_loop:
    read/file {fid(1)} line
    if fid(2) .gt. 0 then
        fid(2) = fid(2) + 1
        line({fid(2)}:) = " CALIB"
        write/file {sid(1)},key line
        goto cal_loop
    endif

    close/file {fid(1)}
endif
close/file {sid(1)}

!Old way
!cmdLine = "esorex " // esorex_opt // recipeSpecs 

cmdLine = "esorex_cmd_file"
outputi = m$system(cmdLine)
!-copy "{logFile}" $DFS_LOG

if outputi(1) .ne. 0 then
  return 1
endif

write/keyword npaf/i/1/1 0
$ls *.paf | $wc -l | write/key npaf
if npaf .gt. 0 then
  didPath(5:) = m$symbol("INS_ROOT") // "/SYSTEM/Dictionary"

  didList(5:) = "PRIMARY-FITS,GEN,IRD,CCDDCS,FCDDCS,DPR,OBS,TPL,ASM,PRO," // -
                "UVES_ICS,UVES_OS,DETMON_QC"

  cmdLine = "QC1LogWriter -s UVES" // didPath // didList // pafList
  outputi = m$system(cmdLine)
  if outputi(1) .ne. 0 then
    return 1
  endif
endif

log/rec {recipeName} OUT
